const signale = require('signale');
const semver = require('semver');
const path = require('path')
const lodash = require('lodash');
const client = require('./core');
const config = JSON.parse(process.env.config);
const debug = require('debug')(`${config.clientName}:cli`)
// Notify update when process exits
const updater = require('update-notifier');
const pkg = require('../package.json');
const cwd = process.cwd();
updater({ pkg }).notify({ defer: true });

let clientConfig = lodash.merge({ pluginPath: ''}, pkg[config.brandName])

if (client.fs.exists(path.join(cwd, `.${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `.${config.brandName}rc.js`)));
} else if (client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `.${config.brandName}`)));
}


// Node version check
const nodeVersion = process.versions.node;
if (semver.satisfies(nodeVersion, '< 8.9')) {
  signale.error(`Node version must >= 8.9, but got ${nodeVersion}`);
  process.exit(1);
}

// execute system plugin: install, list, publish, dev
client.executeSystemPlugin();
// loader installed plugin from system folder
client.loaderInstalledPlugin(config.npmRoot);
// loader point plugins from config
debug(`clientConfig pluginPath:  ${clientConfig.pluginPath}`)
if (clientConfig.pluginPath) {
  client.loaderConfigPlugin(path.resolve(cwd, clientConfig.pluginPath));
}


// parse argv 
client.program.parse(process.argv);