const path = require('path');
const fs = require('fs')
const shelljs = require('shelljs');
const debug = require('debug')('debug:util')
const lodash = require('lodash');

const config = JSON.parse(process.env.config);
const WHITE_LIST = config.WHITE_LIST;
const PLUGIN_REGEXP = new RegExp(config.PLUGIN_REGEXP, 'ig');

const getPluginNameAndPath = (root) => {
  const list = [];
  let filePath = '';
  const pushPlugin = (name, filePath) => {
    if (isPluginName(name) && fs.existsSync(filePath)) {
      list.push({
        name, 
        path: filePath
      });
    }
  } 

  fs.readdirSync(root).forEach(name => {
    if (WHITE_LIST.indexOf(name) === -1) {
      filePath = path.join(root, name, './index.js');
      pushPlugin(name, filePath);
    } else {
      const depthRoot = path.join(root, name);
      fs.readdirSync(depthRoot).forEach(subName => {
        filePath = path.join(depthRoot, subName, './index.js');
        pushPlugin([name, subName].join('/'), filePath);
      })
    }
  })
  
  return list;
}

const isPluginName = (name = '') => {
  return PLUGIN_REGEXP.test(name)
}

const getNpmConfig = () => {
  shelljs.exec('npm config list', function(code, stdout, stderr) {
    const out = stdout.trim();
    out.replace(/username=\"([^\"]+)"?/, (...args) => {
      lodash.merge(config, {
        username: args[1]
      })
    })

    out.replace(/email=\"([^\"]+)"?/, (...args) => {
      lodash.merge(config, {
        emal: args[1]
      })
    })
  })
}




module.exports = {
  isPluginName,
  getPluginNameAndPath,
  getNpmConfig
}